# -*- coding:utf-8 -*-
"""
:filename: tests.test_po.py
:author: Brigitte Bigi
:contact: contact@sppas.org
:summary: Test the translation system.

.. _This file is part of AudiooPy
..

    Copyright (C) 2024  Brigitte Bigi
    Laboratoire Parole et Langage, Aix-en-Provence, France

    Use of this software is governed by the GNU Affero Public License, version 3.

    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU Affero General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU Affero General Public License for more details.

    You should have received a copy of the GNU Affero General Public License
    along with this program. If not, see <https://www.gnu.org/licenses/>.

    This banner notice must not be removed.

"""

import unittest
import gettext
from unittest.mock import MagicMock
from audioopy.po import textTranslate

# ---------------------------------------------------------------------------


class TestPo(unittest.TestCase):

    def setUp(self) -> None:
        self.mocker = MagicMock()
        self.tt = textTranslate()

    def test_init(self):
        tt = textTranslate()
        translation = tt.translation(domain="audioopy")
        self.assertIsInstance(translation, gettext.GNUTranslations)

    def test_lang_list(self):
        lang_list = textTranslate.get_lang_list("en")
        self.assertIn("en", lang_list)

    def test_error(self):
        tt = textTranslate()

        # The message is an empty string
        result = tt.error("")
        self.assertTrue(result.startswith(":ERROR -1: "))

        # The message is an integer
        result = tt.error(2000)
        self.assertTrue(result.startswith(":ERROR 2000:"))

        self.mocker.translation.return_value.gettext.return_value = "Translated error message"
        self.tt.translation = self.mocker.translation
        self.assertEqual(self.tt.error(2000), ":ERROR 2000: Translated error message")

        # an empty string
        tt = textTranslate()
        result = tt.error("")
        self.assertTrue(result.startswith(":ERROR -1: "))

        # non-ascii string
        result = tt.error("Αυτό είναι ένα σφάλμα.")
        self.assertEqual(result, ":ERROR -1: Αυτό είναι ένα σφάλμα.")

        # the message is non string, non integer
        self.assertEqual(self.tt.error(3.14), ":ERROR -1: Translated error message")
